@@ -70,7 +70,7 @@ for name, sym in [
     ("minutes", "m"),
     ("seconds", "s"),
 ]:
-    timedelta_pattern += r"((?P<{}>(?:\+|-)\d+?){})?".format(name, sym)
+    timedelta_pattern += rf"((?P<{name}>(?:\+|-)\d+?){sym})?"
 
 
 class Provider(BaseProvider):
@@ -79,15 +79,15 @@ class Provider(BaseProvider):
     #       appropriate to generate random seconds with.
     if platform.system() == "Windows":
 
-        @property
-        def _rand_seconds(self) -> Callable[[int, int], int]:
-            return self.generator.random.randint
+        def _rand_seconds(self, start_datetime: int, end_datetime: int) -> float:
+            return self.generator.random.randint(start_datetime, end_datetime)
 
     else:
 
-        @property
-        def _rand_seconds(self) -> Callable[[float, float], float]:
-            return self.generator.random.uniform
+        def _rand_seconds(self, start_datetime: int, end_datetime: int) -> float:
+            if start_datetime > end_datetime:
+                raise ValueError("empty range for _rand_seconds: start datetime must be before than end datetime")
+            return self.generator.random.uniform(start_datetime, end_datetime)
 
     centuries: ElementsType[str] = [
         "I",
@@ -1426,7 +1426,7 @@ class Provider(BaseProvider):
         ),
         Country(
             timezones=[
-                "Europe/Kiev",
+                "Europe/Kyiv",
                 "Europe/Uzhgorod",
                 "Europe/Zaporozhye",
                 "Europe/Simferopol",
@@ -1435,7 +1435,7 @@ class Provider(BaseProvider):
             alpha_3_code="UKR",
             continent="Europe",
             name="Ukraine",
-            capital="Kiev",
+            capital="Kyiv",
         ),
         Country(
             timezones=["Africa/Kampala"],
