@@ -18,6 +18,8 @@ class Provider(BaseProvider):
         "safari",
     )
 
+    # source
+    # https://en.wikipedia.org/wiki/Microsoft_Windows
     windows_platform_tokens: ElementsType[str] = (
         "Windows 95",
         "Windows 98",
@@ -32,12 +34,15 @@ class Provider(BaseProvider):
         "Windows NT 6.1",
         "Windows NT 6.2",
         "Windows NT 10.0",
+        "Windows NT 11.0",
     )
 
     linux_processors: ElementsType[str] = ("i686", "x86_64")
 
     mac_processors: ElementsType[str] = ("Intel", "PPC", "U; Intel", "U; PPC")
 
+    # source
+    # https://en.wikipedia.org/wiki/Android_version_history
     android_versions: ElementsType[str] = (
         "1.0",
         "1.1",
@@ -101,23 +106,52 @@ class Provider(BaseProvider):
         "9",
         "10",
         "11",
+        "12",
+        "12.1",
+        "13",
+        "14",
     )
 
     apple_devices: ElementsType[str] = ("iPhone", "iPad")
 
+    # sources
+    # https://en.wikipedia.org/wiki/IOS_version_history
     ios_versions: ElementsType[str] = (
+        "1.1.5",
+        "2.2.1",
         "3.1.3",
+        "3.2.2",
         "4.2.1",
+        "4.3.5",
         "5.1.1",
         "6.1.6",
         "7.1.2",
+        "8.4.1",
         "9.3.5",
         "9.3.6",
         "10.3.3",
         "10.3.4",
+        "11.4.1",
+        "12.4.4",
         "12.4.8",
+        "12.5.7",
+        "13.5.1",
+        "13.7",
         "14.2",
         "14.2.1",
+        "14.8.1",
+        "15.8.2",
+        "16.7.6",
+        "16.7.7",
+        "17.1",
+        "17.1.1",
+        "17.1.2",
+        "17.2",
+        "17.2.1",
+        "17.3",
+        "17.3.1",
+        "17.4",
+        "17.4.1",
     )
 
     def mac_processor(self) -> str:
@@ -168,7 +202,7 @@ class Provider(BaseProvider):
                 saf,
             ),
             tmplt.format(
-                "Linux; {}".format(self.android_platform_token()),
+                f"Linux; {self.android_platform_token()}",
                 saf,
                 self.generator.random.randint(version_from, version_to),
                 self.generator.random.randint(build_from, build_to),
@@ -203,7 +237,7 @@ class Provider(BaseProvider):
         tmplt_mac: str = "({0}; rv:1.9.{1}.20) {2}"
         tmplt_and: str = "({0}; Mobile; rv:{1}.0) Gecko/{1}.0 Firefox/{1}.0"
         tmplt_ios: str = "({0}) AppleWebKit/{1} (KHTML, like Gecko) FxiOS/{2}.{3}.0 Mobile/{4} Safari/{1}"
-        saf: str = "{}.{}".format(self.generator.random.randint(531, 536), self.generator.random.randint(0, 2))
+        saf: str = f"{self.generator.random.randint(531, 536)}.{self.generator.random.randint(0, 2)}"
         bld: str = self.lexify(self.numerify("##?###"), string.ascii_uppercase)
         bld2: str = self.lexify(self.numerify("#?####"), string.ascii_lowercase)
         platforms: ElementsType[str] = (
